Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/pylint_sort_functions/__init__.py | 4 | 0 | 2 | 100%
src/pylint_sort_functions/auto_fix.py | 393 | 0 | 21 | 100%
src/pylint_sort_functions/checker.py | 168 | 0 | 3 | 100%
src/pylint_sort_functions/cli.py | 140 | 0 | 46 | 100%
src/pylint_sort_functions/file_operations.py | 56 | 0 | 5 | 100%
src/pylint_sort_functions/messages.py | 1 | 0 | 0 | 100%
src/pylint_sort_functions/privacy_analyzer.py | 129 | 0 | 5 | 100%
src/pylint_sort_functions/privacy_fixer.py | 179 | 0 | 0 | 100%
src/pylint_sort_functions/privacy_types.py | 22 | 0 | 0 | 100%
src/pylint_sort_functions/test_file_manager.py | 61 | 0 | 0 | 100%
src/pylint_sort_functions/test_file_updater.py | 87 | 0 | 0 | 100%
src/pylint_sort_functions/utils/__init__.py | 7 | 0 | 0 | 100%
src/pylint_sort_functions/utils/ast_analysis.py | 18 | 0 | 0 | 100%
src/pylint_sort_functions/utils/categorization.py | 87 | 0 | 0 | 100%
src/pylint_sort_functions/utils/decorators.py | 50 | 0 | 0 | 100%
src/pylint_sort_functions/utils/file_patterns.py | 48 | 0 | 1 | 100%
src/pylint_sort_functions/utils/privacy.py | 96 | 0 | 4 | 100%
src/pylint_sort_functions/utils/sorting.py | 109 | 0 | 0 | 100%
Total | 1655 | 0 | 87 | 100%

No items found using the specified filter.